pub fn get() -> &'static str {
    "get"
}

pub fn self_module_name() -> &'static str {
    "libflo"
}
